import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjgk_page.gzkgl_page import GzkglPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('规则库管理')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_gzkgl(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
    page.wait(2)
    # 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info('------------进入数据管控质量规则管理模块-------------')


@allure.feature('规则库管理')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_规则库管理')
def test_menu_gzkgl(browser, data):
    page = MenuPage(browser)
    page.table_manage()
    page.menu_icon()
    page.menu_sjgk()
    page.sjgk_sjzl_gzkgl()
    # 切换iframe
    page.sjgk_gzkgl_iframe()
    page.assert_att("编码规则")
    logger.info('01进入菜单成功')


@allure.feature('规则库管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/gzkgl.yaml'))
@allure.title('新增1_规则库管理')
def test_add_gzkgl(browser, data):
    page = GzkglPage(browser)
    page.button_add()
    page.assert_att("新增检查规则")
    page.input_checktheme(data['checktheme'])
    page.input_checkmodule()
    page.input_checkclass()
    page.input_checktitle(data['checktitle'])
    page.input_checkname(data['checkname'])
    page.input_checkrule(data['checkrule'])
    page.input_text(data['text'])
    page.core_switch()
    page.input_sjwdsm(data['sjwdsm'])
    page.icon_plus()
    page.input_wdsmora(data['wdsmora'])
    page.input_wdsmtable(data['wdsmtable'])
    page.input_wdsmcol(data['wdsmcol'])
    page.input_sos(data['sos'])
    page.input_dos(data['dos'])
    page.down_mouse()
    page.icon_pplus()
    page.input_stable(data['stable'])
    page.input_scol(data['scol'])
    page.input_dtable(data['dtable'])
    page.input_dcol(data['dcol'])
    page.button_nextstep()
    page.assert_att("美化SQL")
    logger.info('02新增--可视化编辑')


@allure.feature('规则库管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/gzkgl.yaml'))
@allure.title('新增2_规则库管理')
def test_add2_gzkgl(browser, data):
    page = GzkglPage(browser)
    page.up_mouse()
    page.local_sql()
    page.allselect_keys()
    page.backspace_keys()
    page.key_word()
    page.button_mhsql()
    page.button_sumbit()
    page.assert_att("所有分类")
    logger.info('03新增--直接编辑')


@allure.feature('规则库管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/gzkgl.yaml'))
@allure.title('查询_规则库管理')
def test_search_gzkgl(browser, data):
    page = GzkglPage(browser)
    page.input_search('error')
    page.assert_att('暂无数据')
    page.input_search(data['checkrule'])
    page.assert_att(data['checkrule'])
    logger.info('04查询成功')


@allure.feature('规则库管理')
@allure.title('启停_规则库管理')
def test_rulevalid_gzkgl(browser):
    page = GzkglPage(browser)
    page.button_checkvalid()
    page.assert_att("停用")
    page.button_checkvalid()
    page.assert_att("有效")
    logger.info('05启停成功')


@allure.feature('规则库管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/gzkgl.yaml'))
@allure.title('编辑_规则库管理')
def test_edit_gzkgl(browser, data):
    page = GzkglPage(browser)
    page.button_edit()
    page.input_checkrule("s")
    page.button_nextstep()
    page.button_sumbit()
    page.input_search(data['checkrule']+'s')
    page.assert_att(data['checkrule']+'s')
    logger.info("06编辑成功")


@allure.feature('规则库管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/gzkgl.yaml'))
@allure.title('删除_规则库管理')
def test_remove_gzkgl(browser, data):
    page = GzkglPage(browser)
    page.button_remove()
    page.assert_att('暂无数据')
    logger.info('07删除成功')


@allure.feature('规则库管理')
@allure.title('退出登录')
def test_gzkgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att('赢和数据')
    logger.info('.....退出登录.....')




# 从关键字文件导入基类

from yhproject_pkg.framework.key_word.keyword_web import WebKeys
import pyautogui


class JkcjPage(WebKeys):
    # 创建接口
    def button_add(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/button").click()
        self.wait(3)
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div[1]/div/div[2]/div/span/p").click()
        self.wait(3)

    def input_sjymc(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div[1]/div/div[2]/div/form/div[1]/div[2]/div/div[1]/div/div/div/input").send_keys(words_key)
        self.down_keys()
        self.wait(2)
        self.enter_keys()
        self.wait(2)

    def input_sjbmc(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div[1]/div/div[2]/div/form/div[1]/div[2]/div/div[2]/div/input").send_keys(words_key)
        self.down_keys()
        self.wait(2)
        self.enter_keys()
        self.wait(2)

    def drog_aa(self):
        pyautogui.moveTo(x=400, y=800, duration=1, tween=pyautogui.linear)  # 移动鼠标
        pyautogui.dragTo(x=1000, y=600, duration=1, button='left')

        pyautogui.moveTo(x=400, y=900, duration=1, tween=pyautogui.linear)  # 移动鼠标
        pyautogui.dragTo(x=1000, y=600, duration=1, button='left')

        pyautogui.moveTo(x=400, y=1000, duration=1, tween=pyautogui.linear)  # 移动鼠标
        pyautogui.dragTo(x=1000, y=600, duration=1, button='left')

    def button_jkcs1(self):
        el_jkcs1 = self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div[1]/div/div[2]/div/form/div[2]/div/div[2]/div[1]/div/button[4]")
        el_jkcs1.click()
        self.wait(2)

    def button_jkcs2(self):
        pyautogui.click(1500, 440)
        self.wait(2)

    def input_jkbm(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div[1]/div/div[2]/div/form/div[3]/div[1]/div/div/div/div[1]/input").send_keys(words_key)
        self.wait(2)

    def input_jkmc(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div[1]/div/div[2]/div/form/div[3]/div[3]/div/div/div/div[1]/input").send_keys(words_key)
        self.wait(2)

    def input_ywzt(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div[1]/div/div[2]/div/form/div[3]/div[4]/div/div/div/div/div[1]/div[1]/div[2]/input").click()
        self.enter_keys()
        self.wait(2)

    def input_jkms(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div[1]/div/div[2]/div/form/div[3]/div[5]/div/div/div/div/textarea").send_keys(words_key)

    def button_save(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div[1]/div/div[3]/div/button[2]").click()

    # 接口查询
    def input_seach_jkmc(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/div[1]/div/div/input").send_keys(search_key)

    def button_search(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[1]/span").click()
        self.wait(3)

    def button_reset(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[2]").click()

    # 接口测试
    def button_test(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div[4]/div[2]/table/tbody/tr/td[8]/div/button[2]/span").click()
        self.wait(2)

    def button_apitest(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div[2]/div/div/div/form/div/div[2]/div/div[7]/div/span[2]/button").click()
        self.wait(2)

    def input_edit_jkms(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div[2]/div/div/div/form/div/div[2]/div/div[10]/div/div/textarea").send_keys(words_key)

    def button_edit_save(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div[2]/div/div/div/form/div/div[2]/div/div[11]/button[1]").click()

    def button_edit_back(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div[2]/div/div/div/form/div/div[2]/div/div[11]/button[2]").click()
        self.wait(2)

    # 接口提交
    def button_submit(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div[4]/div[2]/table/tbody/tr[1]/td[8]/div/button[1]/span/i").click()
        self.wait(2)


from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class FjglPage(WebKeys):
    def button_fjgl(self):
        self.locator("xpath", "//*[@id='tab-tab1']").click()
        self.wait(2)

    # 新建
    def button_sjadd(self):
        self.locator("xpath", "//*[@id='pane-tab1']/div/div/div/div[1]/div[1]/button[1]").click()
        self.wait(2)

    def input_sjlevel(self, words_key):
        self.locator("xpath", "//*[@id='pane-tab1']/div/div/div/div[4]/div/div/div[2]/form/div[1]/div/div/div/input").send_keys(words_key)
        self.wait(2)
        self.up_keys()
        self.enter_keys()

    def input_sjlevelname(self, words_key):
        self.locator("xpath", "//*[@id='pane-tab1']/div/div/div/div[4]/div/div/div[2]/form/div[2]/div/div/input").send_keys(words_key)
        self.wait(2)

    def input_sjleveldetail(self, words_key):
        self.locator("xpath", "//*[@id='pane-tab1']/div/div/div/div[4]/div/div/div[2]/form/div[3]/div/div[1]/input").send_keys(words_key)

    def input_sjremark(self, words_key):
        self.locator("xpath", "//*[@id='pane-tab1']/div/div/div/div[4]/div/div/div[2]/form/div[4]/div/div/input").send_keys(words_key)
        self.wait(2)

    def button_sjqr(self):
        self.locator("xpath", "//*[@id='pane-tab1']/div/div/div/div[4]/div/div/div[3]/span/button[2]").click()
        self.wait(1)

    # 编辑
    def button_sjedit(self):
        self.locator("xpath", "//*[@id='pane-tab1']/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr/td[9]/div/button[1]").click()
        self.wait(2)

    # 删除
    def button_remove(self):
        self.locator("xpath", "//*[@id='pane-tab1']/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr/td[9]/div/button[2]").click()
        self.wait(2)
        self.enter_keys()
        self.wait(2)

    # 查询
    def input_search(self, word_keys):
        self.locator("xpath", "//*[@id='pane-tab1']/div/div/div/div[1]/div[2]/input").send_keys(word_keys)
        self.wait(2)
        self.locator("xpath", "//*[@id='pane-tab1']/div/div/div/div[1]/button[1]").click()
        self.wait(2)

    def button_reset(self):
        self.locator("xpath", "//*[@id='pane-tab1']/div/div/div/div[1]/button[2]").click()
        self.wait(2)

    # 版本管理
    def button_vermg(self):
        self.locator("xpath", "//*[@id='tab-tab2']").click()
        self.wait(3)

    def button_veradd(self):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[1]/div[1]/button[1]").click()

    def input_verid(self, word_keys):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[1]/div[1]/div/div/div[1]/input").send_keys(word_keys)

    def input_vername(self, word_keys):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[1]/div[2]/div/div/div[1]/input").send_keys(word_keys)

    def input_vertext(self, word_keys):
        self.locator("xpath","//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[2]/div/div[1]/input").send_keys(word_keys)
        self.wait(2)

    def button_addline(self):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[4]/div/button").click()
        self.wait(2)

    def input_mglevelid(self, word_keys):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[5]/div/div/div[3]/table/tbody/tr/td[2]/div/div/div/div/div/div/input").send_keys(word_keys)
        self.wait(1)
        self.up_keys()
        self.enter_keys()

    def input_mglevelname(self, word_keys):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[5]/div/div/div[3]/table/tbody/tr/td[3]/div/div/div/div/div[1]/input").send_keys(word_keys)

    def input_mgleveldetail(self, word_keys):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[5]/div/div/div[3]/table/tbody/tr/td[4]/div/div/div/div/div[1]/input").send_keys(word_keys)

    def box_checkture(self):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[5]/div/div/div[3]/table/tbody/tr/td[6]/div/button[1]").click()

    def input_mglevelid1(self, word_keys):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[5]/div/div/div[3]/table/tbody/tr[2]/td[2]/div/div/div/div/div/div/input").send_keys(word_keys)
        self.wait(1)
        self.up_keys()
        self.enter_keys()

    def input_mglevelname1(self, word_keys):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[5]/div/div/div[3]/table/tbody/tr[2]/td[3]/div/div/div/div/div[1]/input").send_keys(word_keys)

    def input_mgleveldetail1(self, word_keys):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[5]/div/div/div[3]/table/tbody/tr[2]/td[4]/div/div/div/div/div[1]/input").send_keys(word_keys)

    def box_checkture1(self):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[2]/form/div[5]/div/div/div[3]/table/tbody/tr[2]/td[6]/div/button[1]").click()

    def button_levelqr(self):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[4]/div/div/div[3]/span/button[2]").click()
        self.wait(2)

    def input_mgsearch(self, search_key):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[1]/div[2]/input").send_keys(search_key)
        self.wait(2)
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[1]/button[1]").click()
        self.wait(2)

    def button_mgreset(self):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[1]/button[2]").click()

    # 开关切换
    def button_switch(self):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr/td[10]/div/button[1]/span").click()
        self.wait(2)
        self.enter_keys()
        self.wait(2)

    # 编辑
    def button_veredit(self):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr/td[10]/div/button[2]").click()
        self.wait(2)

    def button_verremove(self):
        self.locator("xpath", "//*[@id='pane-tab2']/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr/td[10]/div/button[3]").click()
        self.wait(2)











import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjfw_page.ywztgl_page import YwztglPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('业务主题管理')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_ztgl(browser, data):
    page = LoginPage(browser)
    page.open(data["url"])
    page.driver.maximize_window()
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
# 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info('------------进入业务主题管理模块-------------')


@allure.feature('业务主题管理')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_业务主题管理')
def test_menu_ztgl(browser, data):
    page = MenuPage(browser)
    page.table_manage()
    page.menu_icon()
    page.menu_sjfw()
    page.sjfw_sjfw_ywztgl()
    logger.info('业务主题管理_打开菜单')
    # 切换iframe
    page.sjfw_yeztgl_iframe()
    page.assert_att("主题名称")
    logger.info('01进入菜单')


@allure.feature('业务主题管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/ywztgl.yaml'))
@allure.title('新增业务主题')
def test_ztgl_add(browser, data):
    page = YwztglPage(browser)
    page.button_add()
    page.input_ztmc(data["ztmc001"])
    page.input_order(data["order001"])
    page.input_ztms(data["ztms001"])
    page.button_qr()
    page.assert_att('操作成功')
    logger.info("02新增主题成功")


@allure.feature('业务主题管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/ywztgl.yaml'))
@allure.title('查询业务主题')
def test_ztgl_search(browser, data):
    page = YwztglPage(browser)
    page.input_search("error")
    page.assert_att("暂无数据")
    page.button_reset()
    page.input_search(data["ztmc001"])
    page.assert_att(data["ztmc001"])
    logger.info("业务主题管理管理_查询成功")


@allure.feature('业务主题管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/ywztgl.yaml'))
@allure.title('编辑业务主题')
def test_ztgl_edit(browser, data):
    page = YwztglPage(browser)
    page.button_edit()
    page.input_ztms('s')
    page.button_qr()
    page.assert_att(data["ztms001"]+'s')
    logger.info("04编辑业务主题成功")


@allure.feature('业务主题管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/ywztgl.yaml'))
@allure.title('删除业务主题')
def test_ztgl_remove(browser, data):
    page = YwztglPage(browser)
    page.button_remove()
    page.enter_keys()
    page.assert_att("暂无数据")
    logger.info("05删除主题成功")


@allure.feature('业务主题管理')
@allure.title('退出登录')
def test_ywztgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')






import pytest
from selenium import webdriver
chrome_driver = r"C:\Program Files\Google\Chrome\Application\chromedriver.exe"
import os
import allure


_driver = None


@pytest.hookimpl(tryfirst=True, hookwrapper=True)
def pytest_runtest_makereport(item, call):
    # 获取钩子方法的调用结果
    outcome = yield
    rep = outcome.get_result()
    # 仅仅获取用例call 执行结果是失败的情况, 不包含 setup/teardown
    if rep.when == "call" and rep.failed:
        mode = "a" if os.path.exists("failures") else "w"
        with open("failures", mode) as f:
            # let's also access a fixture for the fun of it
            if "tmpdir" in item.fixturenames:
                extra = " (%s)" % item.funcargs["tmpdir"]
            else:
                extra = ""
            f.write(rep.nodeid + extra + "\n")
        # 添加allure报告截图
        with allure.step('添加失败截图...'):
            allure.attach(_driver.get_screenshot_as_png(), "失败截图", allure.attachment_type.PNG)


@pytest.fixture(scope='session')
def browser():
    global _driver
    if _driver is None:
        _driver =webdriver.Chrome(executable_path=chrome_driver)
    yield _driver
    _driver.quit()



import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjgk_page.tmgz_page import TmgzPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('脱敏规则')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_tmgz(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
# 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info('------------进入脱敏规则模块-------------')


@allure.feature('脱敏规则')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_脱敏规则')
def test_menu_tmgz(browser, data):
    page = MenuPage(browser)
    page.open(data["url"])
    page.table_manage()
    page.menu_icon()
    page.menu_sjgk()
    page.sjgk_sjaq_tmgz()
    # 切换iframe
    page.sjgk_tmgz_iframe()
    page.assert_att("规则名称")
    logger.info('01进入菜单')


@allure.feature('脱敏规则')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/tmgz.yaml'))
@allure.title('新增_脱敏规则')
def test_add_tmgz(browser, data):
    page = TmgzPage(browser)
    page.button_add()
    page.input_gzmc(data['gzmc'])
    page.input_gzbm(data['gzbm'])
    page.input_gzdj(data['gzdj'])
    page.input_bds('2', '4')
    page.input_thfh('***')
    page.input_gzms(data['gzms'])
    page.button_save()
    logger.info('02新增成功1')


@allure.feature('脱敏规则')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/tmgz.yaml'))
@allure.title('新增_脱敏规则1')
def test_add1_tmgz(browser, data):
    page = TmgzPage(browser)
    page.button_add()
    page.input_gzmc(data['gzmc1'])
    page.input_gzbm(data['gzbm1'])
    page.input_gzdj(data['gzdj1'])
    page.input_gzlx()
    page.input_gzmy(data['gzmy1'])
    page.input_gzms(data['gzms1'])
    page.button_save()
    logger.info('03新增成功2')


@allure.feature('脱敏规则')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/tmgz.yaml'))
@allure.title('新增_脱敏规则2')
def test_add2_tmgz(browser, data):
    page = TmgzPage(browser)
    page.button_add()
    page.input_gzmc(data['gzmc2'])
    page.input_gzbm(data['gzbm2'])
    page.input_gzdj(data['gzdj2'])
    page.input_bds('2', '4')
    page.input_thfh('***')
    page.input_gzms(data['gzms2'])
    page.button_save()
    logger.info('04新增成功3')


@allure.feature('脱敏规则')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/tmgz.yaml'))
@allure.title('搜索_脱敏规则')
def test_search_tmgz(browser, data):
    page = TmgzPage(browser)
    page.input_search('error')
    page.assert_att('暂无数据')
    page.button_reset()
    page.input_search(data['gzmc'])
    page.assert_att(data["gzmc"])
    logger.info('05查询成功')


@allure.feature('脱敏规则')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/tmgz.yaml'))
@allure.title('编辑_脱敏规则')
def test_edit_tmgz(browser, data):
    page = TmgzPage(browser)
    page.button_setting()
    page.assert_att("编辑")
    page.button_edit()
    page.assert_att('编辑')
    page.input_egzmc('sss')
    page.button_esave()
    page.button_reset()
    page.input_search('sss')
    page.assert_att('sss')
    logger.info('06编辑成功')


@allure.feature('脱敏规则')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/tmgz.yaml'))
@allure.title('删除_脱敏规则')
def test_remove_tmgz(browser, data):
    page = TmgzPage(browser)
    page.button_eremove()
    page.assert_att('暂无数据')
    logger.info('07删除成功')


@allure.feature('脱敏规则')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/tmgz.yaml'))
@allure.title('批量删除_脱敏规则')
def test_remove_etmgz(browser, data):
    page = TmgzPage(browser)
    page.button_reset()
    page.input_search(data['gzmc1'])
    page.assert_att(data['gzmc1'])
    page.box_check()
    page.button_remove()
    page.assert_att('暂无数据')
    logger.info('08批量删除成功')


@allure.feature('脱敏规则')
@allure.title('退出登录')
def test_tmgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')




import logging
from time import sleep
import os
import time
import win32api
import win32con
from selenium.webdriver.common.action_chains import ActionChains
from selenium.webdriver.common.keys import Keys



# 构造工具包
class WebKeys():
    # 创建webdriver驱动
    def __init__(self, driver):
        self.driver = driver

    # 访问URL
    def open(self, url):
        self.driver.get(url)
        self.wait(2)

    # 退出
    def quit(self):
        self.driver.quit()

    # 元素定位
    def locator(self, name, value):
        return self.driver.find_element(name, value)

    def locators(self, name, value):
        return self.driver.find_elements(name, value)

    # 输入
    def input(self, name, value, txt):
        el = self.locator(name, value)
        el.clear()
        el.send_keys(txt)

    # 强制等待
    def wait(self, time_):
        sleep(time_)

    # 断言
    def assert_att(self, word):
        try:
            att = self.driver.find_element_by_xpath('//*[contains(text(),\"' + word + '\")]').text
            return True

        except AssertionError as e:
            logging.error("There is AssertError!")
            return False

    # 窗口切换
    def switch_window(self, n):
        self.driver.switch_to.window(self.driver.window_handles[n])

    # iframe切换
    def switch_iframe(self, name, value):
        self.driver.switch_to.frame(self.locator(name, value))

    # 释放iframe
    def reback_iframe(self):
        self.driver.switch_to.default_content()
        self.wait(2)

    # 截图方法
    def get_windows_img(self):
        file_path = os.path.dirname(os.path.abspath('')) + '/img/'  # 设置截图保存路径
        rq = time.strftime('%Y%m%d%H%M%S', time.localtime(time.time()))  # 获取当前系统时间
        img_name = file_path + rq + '.png'  # 设置截图名称格式
        try:
            self.driver.get_screenshot_as_file(img_name)  # 指定截图存放路径和名称
            print("已将截图保存到文件夹/img/img")
        except NameError as e:
            print("截图保存失败! %s" % e)
            self.get_windows_img()

    # 模拟按键enter
    def enter_keys(self):
        ActionChains(self.driver).send_keys(Keys.ENTER).perform()
        self.wait(2)

    # 模拟按键下
    def down_keys(self):
        ActionChains(self.driver).send_keys(Keys.DOWN).perform()
        self.wait(1)

    # 模拟按键上
    def up_keys(self):
        ActionChains(self.driver).send_keys(Keys.UP).perform()
        self.wait(1)

    # 模拟回车键
    def backspace_keys(self):
        ActionChains(self.driver).send_keys(Keys.BACK_SPACE).perform()
        sleep(2)

    # 模拟全选键
    def allselect_keys(self):
        action = ActionChains(self.driver)
        action.key_down(Keys.CONTROL).send_keys('a').key_up(Keys.CONTROL)  # CTRL+A
        action.perform()  # 执行
        sleep(2)

    # 模拟鼠标中轴向下滚动
    def down_mouse(self):
        for i in range(1, 1500):
            win32api.mouse_event(win32con.MOUSEEVENTF_WHEEL, 0, 0, -1)
        sleep(1)

    # 模拟鼠标中轴向上滚动
    def up_mouse(self):
        for i in range(1, 1500):
            win32api.mouse_event(win32con.MOUSEEVENTF_WHEEL, 0, 0, 1)
        sleep(1)













# from selenium import webdriver
#
#
# class DriverUtil():
#     def __init__(self):
#         self.driver = webdriver.Chrome()
#
#     def start(self):
#         self.driver.get("http://eid.csrc.gov.cn/")
#         return self.driver


import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('元数据管理')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_ysjgl(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
    # 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info('------------进入元数据管理模块-------------')


@allure.feature('元数据管理')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_元数据管理')
def test_menu_ysjgl(browser, data):
    page = MenuPage(browser)
    page.table_manage()
    page.menu_icon()
    page.menu_sjgk()
    page.sjgk_ysj_ysjgl()
    logger.info('打开菜单成功')


@allure.feature('元数据管理')
@allure.title('退出登录')
def test_ysjgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')





# import sys
# sys.path.append(r"C:\Users\胡小锋\PycharmProjects\pythonProject")
import logging
import pytest
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.demo_page0 import BaiduPage
import allure

logger = logging.getLogger(__name__)


@allure.feature('百度搜索')


class TestLogin():
    @pytest.mark.parametrize('data', load_yaml('../../data/demo/login_demo2.yaml'))
    def test_login012(self, data, t):
        page = BaiduPage(t)
        print("还在当前页面")

        # t.WebKeys.locator(data["name_xpath"],data["value2"]).click()
        page.button_ssgs()
        # t.find_element_by_xpath(data["value2"]).click
        print("点击成功")
        # assert "上市" in t.find_element_by_link_text("上市公司").text
        # page.assert_att("上市公司")

        page.wait(1)
        page.quit()
        print('测试3')


logger.info("TestLogin")



if __name__ == '__main__':
    pytest.main(['test_demo1.py'])




# 从关键字文件导入基类
from pynput.keyboard import Controller

from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class GzkglPage(WebKeys):
    def button_add(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/div[1]/button[1]").click()
        self.wait(2)

    def input_checktheme(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[1]/div[1]/div/div/div/input").send_keys(key_words)
        self.down_keys()
        self.enter_keys()
        self.wait(2)

    def input_checkmodule(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[1]/div[3]/div/div/div[1]/input").click()
        self.down_keys()
        self.enter_keys()
        self.wait(2)

    def input_checkclass(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[1]/div[4]/div/div/div/input").click()
        self.down_keys()
        self.enter_keys()
        self.wait(2)

    def input_checktitle(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[1]/div[5]/div/div[1]/input").send_keys(key_words)
        self.wait(2)

    def input_checkname(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[1]/div[6]/div/div/input").send_keys(key_words)
        self.wait(2)

    def input_checkrule(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[1]/div[7]/div/div[1]/input").send_keys(key_words)
        self.wait(2)

    def input_text(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[1]/div[9]/div/div/textarea").send_keys(key_words)
        self.wait(3)

    def core_switch(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[1]/div/div/span[1]").click()

    def input_sjwdsm(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[2]/div/div/input").send_keys(key_words)

    def icon_plus(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[3]/div/div/div[2]/table/thead/tr/th[4]/div/div").click()

    def input_wdsmora(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[3]/div/div/div[3]/table/tbody/tr/td[1]/div/div/div/div/div/div/input").send_keys(key_words)
        self.wait(2)
        self.down_keys()
        self.enter_keys()
        self.wait(3)

    def input_wdsmtable(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[3]/div/div/div[3]/table/tbody/tr/td[2]/div/div/div/div/div/div/input").send_keys(key_words)
        self.wait(2)
        self.down_keys()
        self.enter_keys()
        self.wait(3)

    def input_wdsmcol(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[3]/div/div/div[3]/table/tbody/tr/td[3]/div/div/div/div/div/div/input").send_keys(key_words)
        self.wait(2)
        self.down_keys()
        self.enter_keys()
        self.wait(3)

    def input_sos(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[4]/div/div/div/input").send_keys(key_words)
        self.wait(2)
        self.down_keys()
        self.enter_keys()
        self.wait(3)

    def input_dos(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[6]/div/div/div/input").send_keys(key_words)
        self.wait(2)
        self.down_keys()
        self.enter_keys()
        self.wait(3)

    def icon_pplus(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[8]/div/div/div[2]/table/thead/tr[2]/th[5]/div/div").click()

    def input_stable(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[8]/div/div/div[3]/table/tbody/tr/td[1]/div/div/div/div/div/div/input").send_keys(key_words)
        self.wait(2)
        self.down_keys()
        self.enter_keys()
        self.wait(3)

    def input_scol(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[8]/div/div/div[3]/table/tbody/tr/td[2]/div/div/div/div/div/div[1]/input").send_keys(key_words)
        self.wait(2)
        self.down_keys()
        self.enter_keys()
        self.wait(3)

    def input_dtable(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[8]/div/div/div[3]/table/tbody/tr/td[3]/div/div/div/div/div/div/input").send_keys(key_words)
        self.wait(2)
        self.down_keys()
        self.enter_keys()
        self.wait(3)

    def input_dcol(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[2]/div[8]/div/div/div[3]/table/tbody/tr/td[4]/div/div/div/div/div/div/input").send_keys(key_words)
        self.wait(2)
        self.down_keys()
        self.enter_keys()
        self.wait(3)

    def button_nextstep(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[3]/span/button[2]/span").click()
        self.wait(2)

    def local_sql(self):
        el = self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[3]/div[1]/div/div[2]/div/div[6]/div[1]/div/div/div/div[5]/div[4]/pre")
        el.click()
        self.wait(3)

    def input_sql(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[3]/div[1]/div/div[2]/div/div[6]/div[1]/div/div/div/div[5]/div/pre").send_keys(key_words)

    def button_sumbit(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[3]/span/button[3]").click()
        self.wait(2)

    def key_word(self):
        keyboard = Controller()
        keyboard.type('SELECT X.S_VALUE, X.D_VALUE, X.DIFF_VALUE '
                      'FROM (SELECT SUM(CASE TYPE WHEN 1 THEN 1 ELSE 0 END) AS S_VALUE,SUM(CASE TYPE WHEN 2 THEN 1 ELSE 0 END) AS D_VALUE,'
                      'SUM((CASE TYPE WHEN 2 THEN 1 ELSE 0 END) - (CASE TYPE WHEN 1 THEN 1 ELSE 0 END)) AS DIFF_VALUE FROM (SELECT 1 AS TYPE,V1.OS FROM TEST_S_BF_LOG_LOGIN1  V1 GROUP BY V1.OS '
                      'UNION ALL SELECT 2 AS TYPE,E1.OS  FROM TEST_S_BF_LOG_LOGIN1  E1 GROUP BY E1.OS ) T) X WHERE ABS(DIFF_VALUE) > 0')
        self.wait(5)

    def button_mhsql(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[2]/form/div/div[2]/div[3]/div[1]/div/div[1]/button/span").click()
        self.wait(2)

    def input_search(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/div[2]/input").clear()
        self.wait(2)
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/div[2]/input").send_keys(key_words)
        self.wait(2)
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/button").click()
        self.wait(2)

    def button_checkvalid(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div[5]/div[2]/table/tbody/tr[1]/td[18]/div/button[1]").click()
        self.wait(2)
        self.enter_keys()
        self.wait(2)

    def button_edit(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div[5]/div[2]/table/tbody/tr[1]/td[18]/div/button[2]").click()
        self.wait(2)

    def button_remove(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div[5]/div[2]/table/tbody/tr[1]/td[18]/div/button[3]").click()
        self.wait(2)
        self.enter_keys()
        self.wait(2)









# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class JkspPage(WebKeys):
    def input_search(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/div[1]/div/div/input").send_keys(words_key)
        self.wait(3)
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[1]").click()
        self.wait(3)

    def button_reset(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[2]").click()
        self.wait(3)

    def button_tabcheck(self):
        self.locator("xpath", "//*[@id='tab-tabCheck']").click()

    def button_tabreviewed(self):
        self.locator("xpath", "//*[@id='tab-tabReviewed']").click()

    def button_check(self):
        el = self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div[2]/div[3]/div[4]/div[2]/table/tbody/tr/td[7]/div/button[1]/span/i")
        self.driver.execute_script('arguments[0].click();', el)  # 直接点击不可见的目标元素，不再先跳转。
        self.wait(2)

    def button_check_false(self):
        self.locator("xpath", "/html/body/div[2]/div/div[3]/button[1]").click()
        self.wait(5)

    def button_check_ture(self):
        self.locator("xpath", "/html/body/div[2]/div/div[3]/button[2]").click()
        self.wait(5)




# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class TmglPage(WebKeys):
    def input_search(self, key_words):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[1]/div[1]/div/input").send_keys(key_words)
        self.wait(2)
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[1]/div[1]/button[1]").click()
        self.wait(2)

    def button_reset(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[1]/div[1]/button[2]").click()
        self.wait(2)

    def button_manage(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[1]/div[2]/button").click()
        self.wait(2)

    def core_switch(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[2]/div[3]/table/tbody/tr/td[9]/div/div/span[2]").click()
        self.wait(1)

    def button_remove(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr/td[10]/div/div/button").click()
        self.wait(2)
        self.enter_keys()
        self.wait(2)





# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class JkcxPage(WebKeys):
    def input_search(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/div[1]/div/div/input").send_keys(search_key)
        self.wait(2)
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[1]").click()
        self.wait(2)

    def button_reset(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[2]").click()
        self.wait(2)

    def button_apply(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div[4]/div[2]/table/tbody/tr[1]/td[8]/div/button").click()
        self.wait(2)

    def button_appkey(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/button").click()
        self.wait(2)

    def button_close(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div/div[1]/button").click()

    def button_apitest(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div[2]/div/div/div/form/div/div[2]/div/div[9]/div/span[2]/button").click()

    def button_reback(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[4]/div/div[2]/div/div/div/form/div/div[2]/div/div[11]/button").click()



# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class JksxglPage(WebKeys):
    def input_search(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/div[1]/div/div/input").send_keys(search_key)

    def button_search(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[1]").click()
        self.wait(3)

    def button_reset(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[2]").click()
        self.wait(1)

    def button_select(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/div[4]/div[2]/table/tbody/tr/td[8]/div/button[2]").click()
        self.wait(2)

    def button_apitest(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[3]/div/div[2]/div/div/div/form/div/div[2]/div/div[9]/div/span[2]/button").click()
        self.wait(2)

    def button_back(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[3]/div/div[2]/div/div/div/form/div/div[2]/div/div[11]/button").click()

    def button_line(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/div[4]/div[2]/table/tbody/tr/td[8]/div/button[1]").click()




# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class SjtmPage(WebKeys):
    def input_ora(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div[1]/div/div/div[2]/div[1]/input").clear()
        self.wait(2)
        self.locator("xpath", "//*[@id='app']/section/div/div/div[1]/div/div/div[2]/div[1]/input").send_keys(word_keys)
        self.wait(5)

    def input_col(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div[2]/div/div/div[1]/div[2]/div/input").send_keys(word_keys)
        self.wait(2)
        self.locator("xpath", "//*[@id='app']/section/div/div/div[2]/div/div/div[1]/div[2]/button[1]").click()
        self.wait(2)

    def icon_ora(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div[1]/div/div/div[2]/div[2]/div[2]/div[2]/div/div[2]/div/div[2]/div/div[1]/div/div/span").click()
        self.wait(2)

    def icon_tab(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div[1]/div/div/div[2]/div[2]/div[2]/div[2]/div/div[2]/div/div[2]/div/div[2]/div[50]/div[1]/div/div/span").click()
        self.wait(5)

    def button_reset(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div[2]/div/div/div[1]/div[2]/button[2]").click()
        self.wait(2)

    def input_rule(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div[2]/div/div/div[2]/div[3]/table/tbody/tr/td[6]/div/div/div/input").send_keys(word_keys)
        self.up_keys()
        self.enter_keys()
        self.wait(5)









import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjgk_page.sjtm_page import SjtmPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('数据脱敏')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_sjtm(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
    # 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info('------------进入数据脱敏模块-------------')


@allure.feature('数据脱敏')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_数据脱敏')
def test_menu_sjtm(browser, data):
    page = MenuPage(browser)
    browser.get(data['url'])
    page.driver.maximize_window()
    page.table_manage()
    page.menu_icon()
    page.menu_sjgk()
    page.sjgk_sjaq_sjtm()
    # 切换iframe
    page.sjgk_sjtm_iframe()
    page.assert_att("数据脱敏配置")
    logger.info('01进入菜单成功')


@allure.feature('数据脱敏')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/tmgz.yaml'))
@allure.title('定位_数据库表')
def test_local_sjtm(browser, data):
    page = SjtmPage(browser)
    page.input_ora('SHUJUYUAN')
    page.icon_ora()
    page.input_ora(data['table'])
    page.icon_tab()
    page.assert_att(data['table'])
    logger.info('02数据库表定位成功')


@allure.feature('数据脱敏')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/tmgz.yaml'))
@allure.title('查询_数据库表')
def test_place_sjtm(browser, data):
    page = SjtmPage(browser)
    page.input_col('error')
    page.assert_att("暂无数据")
    page.button_reset()
    page.input_col(data['col'])
    page.input_rule(data['gzmc2'])
    page.assert_att(data['gzmc2'])
    logger.info('03配置后查询成功')


@allure.feature('数据脱敏')
@allure.title('退出登录')
def test_tmgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')



# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class LoginPage(WebKeys):
    # 输入账号
    def input_user(self, search_key):
        self.locator("id", "user").clear()
        self.wait(2)
        self.locator("id", "user").send_keys(search_key)

    # 清空账号
    def clear_user(self):
        self.locator("id", "user").clear()

    # 输入密码
    def input_password(self, search_key):
        self.locator("id", "password").send_keys(search_key)

    # 清空密码
    def clear_password(self):
        self.locator("id", "password").clear()

    # 记住我
    def button_remember(self):
        self.locator("xpath", "/html/body/section/section/div[2]/div[2]/div[1]/label[2]").click()

    # 登录
    def button_login(self):
        self.locator("xpath", "/html/body/section/section/div[2]/div[2]/div[5]/button").click()
        self.wait(2)

    # 点击用户
    def button_user(self):
        self.locator("xpath", "/html/body/section/div/section[1]/div[2]/div[2]/span").click()
        self.wait(2)




# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys
import pyautogui


class FlglPage(WebKeys):
    # 新增分类
    def button_add(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/div/div[1]/button").click()

    def input_flmc(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/form/div[1]/div/div[1]/input").send_keys(words_key)

    def input_flcj(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/form/div[2]/div/div/div/input").send_keys(words_key)
        self.wait(2)
        self.down_keys()
        self.wait(2)
        self.enter_keys()

    def button_flqr(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[3]/span/button[2]").click()
        self.wait(1)

    # 关键字搜索
    def input_treesearch(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/div/div[2]/div[1]/input").clear()
        self.wait(1)
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/div/div[2]/div[1]/input").send_keys(search_key)
        self.wait(2)

    def icon_add(self):
        pyautogui.click(694, 554)
        self.wait(3)
        pyautogui.click(710, 620)
        self.wait(2)

    def icon_edit(self):
        pyautogui.click(737, 605)
        self.wait(3)
        pyautogui.click(807, 670)
        self.wait(2)

    def icon_remove(self):
        pyautogui.click(737, 605)
        self.wait(3)
        pyautogui.click(750, 723)
        self.wait(2)
        self.enter_keys()
        self.wait(1)

    def icon_sremove(self):
        pyautogui.click(739, 558)
        self.wait(3)
        pyautogui.click(805, 673)
        self.wait(2)
        self.enter_keys()
        self.wait(1)

    def icon_flmc(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/div/div[2]/div[2]/div[15]/div[1]/div/span").click()
        self.wait(3)

    # 分类明细
    def button_sjadd(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[1]/div[1]/button[1]").click()
        self.wait(3)

    def button_sjremove(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[1]/div[1]/button[2]").click()
        self.wait(2)
        self.enter_keys()
        self.wait(2)

    def input_sjflmc(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[4]/div/div/div[2]/form/div[1]/div/div[1]/input").send_keys(word_keys)
        self.wait(1)
        self.up_keys()
        self.enter_keys()
        self.wait(1)

    def input_sjyjfl(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[4]/div/div/div[2]/form/div[2]/div/div/div/input").send_keys(word_keys)
        self.wait(1)
        self.up_keys()
        self.enter_keys()
        self.wait(1)

    def input_sjejfl(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[4]/div/div/div[2]/form/div[3]/div/div[1]/div/input").send_keys(word_keys)
        self.wait(1)
        self.up_keys()
        self.enter_keys()
        self.wait(1)

    def input_sjsjsyz(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[4]/div/div/div[2]/form/div[4]/div/div/div/input").click()
        self.wait(1)
        self.up_keys()
        self.enter_keys()
        self.wait(1)

    def input_sjtext(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[4]/div/div/div[2]/form/div[5]/div/div[1]/textarea").send_keys(word_keys)
        self.wait(2)

    def button_sjqr(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[4]/div/div/div[3]/span/button[2]").click()
        self.wait(1)

    def input_sjsearch(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[1]/div[2]/input").send_keys(search_key)
        self.wait(2)

    def button_sjsearch(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[1]/button[1]/span").click()
        self.wait(2)

    def icon_boxcheck(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[2]/div[4]/div[2]/table/tbody/tr[1]/td[1]/div/label/span/span").click()

    def icon_sjedit(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr[1]/td[10]/div/button[1]").click()
        self.wait(2)

    def button_sjreset(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[1]/button[2]").click()

    def icon_sjremove(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div/div/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr[1]/td[10]/div/button[2]").click()
        self.wait(2)
        self.enter_keys()
        self.wait(1)



import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjfw_page.jkcx_page import JkcxPage
from yhproject_pkg.framework.page.sjfw_page.jksp_page import JkspPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('接口查询')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_jkcx(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.wait(3)
    page.input_user(data["user1"])
    page.input_password(data["password1"])
    page.button_remember()
    page.button_login()
    page.wait(2)
# 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info("接口查询_登录成功")


@allure.feature('接口查询')
@allure.title('打开菜单_接口查询')
def test_menu_jkcx(browser):
    page = MenuPage(browser)
    page.table_manage()
    page.menu_icon()
    page.menu_sjfw()
    page.sjfw_sjfw_jkcx()
    logger.info('打开菜单_接口查询管理')
    # 切换iframe
    page.sjfw_jkcx_iframe()
    logger.info('进入接口查询管理模块')
    page.assert_att("状态")


@allure.feature('接口查询')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/cjjk.yaml'))
@allure.title('查询接口')
def test_jkcx_search(browser, data):
    page = JkcxPage(browser)
    page.input_search('error')
    page.assert_att('暂无数据')
    page.button_reset()
    page.input_search(data['jkmc2'])
    page.assert_att('不可用')
    logger.info("接口查询_查询接口正常")


@allure.feature('接口查询')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/cjjk.yaml'))
@allure.title('申请接口')
def test_jkcx_apply(browser, data):
    page = JkcxPage(browser)
    page.button_apply()
    page.enter_keys()
    page.wait(1)
    page.assert_att("操作成功")
    page.wait(5)
    page.button_apply()
    page.enter_keys()
    page.wait(1)
    page.assert_att("该接口正在申请中")
    page.wait(3)
    logger.info('接口查询_接口权限申请')


@allure.feature('接口查询')
@allure.title('查看密钥')
def test_jkcx_appkey(browser):
    page = JkcxPage(browser)
    page.button_appkey()
    page.wait(2)
    page.assert_att("appKey")
    page.button_close()
    logger.info('接口查询_接口查询密钥')


@allure.feature('接口查询')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/cjjk.yaml'))
@allure.title('打开菜单_接口审批管理')
def test_menu_jksp(browser, data):
    page = MenuPage(browser)
    page.reback_iframe()
    page.menu_sjfw()
    page.sjfw_sjfw_jksp()
    page.sjfw_jksp_iframe()
    logger.info('接口查询_进入接口审批管理模块')


@allure.feature('接口查询')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/cjjk.yaml'))
@allure.title('接口审批管理通过')
def test_jksp_check(browser, data):
    page = JkspPage(browser)
    page.button_reset()
    page.input_search(data['jkmc2'])
    page.wait(3)
    page.button_check()
    page.wait(1)
    page.button_check_ture()
    page.wait(3)
    logger.info("接口查询_接口审批通过")


@allure.feature('接口查询')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_接口查询管理')
def test_remenu_jkcx1(browser, data):
    page = MenuPage(browser)
    page.reback_iframe()
    page.menu_sjfw()
    page.wait(10)
    page.sjfw_sjfw_jkcx()
    page.wait(10)
    page.sjfw_jkcx_iframe()
    page.wait(3)
    page.assert_att("状态")
    logger.info('接口查询_进入接口查询模块')


@allure.feature('接口查询')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/cjjk.yaml'))
@allure.title('查询接口')
def test_rejkcx_search1(browser, data):
    page = JkcxPage(browser)
    page.button_reset()
    page.input_search(data['jkmc2'])
    page.assert_att('可用')
    page.wait(3)
    logger.info("接口查询_接口申请成功")


@allure.feature('接口查询')
@allure.title('查询接口')
def test_rejkcx_apitest(browser):
    page = JkcxPage(browser)
    page.button_apply()
    page.wait(2)
    page.button_apitest()
    page.wait(2)
    page.assert_att('200')
    page.button_reback()
    page.wait(2)
    logger.info('接口查询_APItest')


@allure.feature('接口查询')
@allure.title('退出登录')
def test_jksxgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')





import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjgk_page.flgl_page import FlglPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('分类管理')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_flgl(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.wait(3)
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
    page.wait(2)
# 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info('------------进入分类管理模块-------------')


@allure.feature('分类管理')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_分类管理')
def test_menu_flgl(browser, data):
    page = MenuPage(browser)
    page.table_manage()
    page.menu_icon()
    page.menu_sjgk()
    page.sjgk_sjflfj_sjfl()
    # 切换iframe
    page.sjgk_sjfl_iframe()
    page.assert_att("数据分类管理")
    logger.info('01进入菜单成功')


@allure.feature('分类管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/flgl.yaml'))
@allure.title('分类管理_新增分类')
def test_flgl_add(browser, data):
    page = FlglPage(browser)
    page.button_add()
    page.input_flmc(data["flmc"])
    page.input_flcj(data["flcj"])
    page.button_flqr()
    logger.info('02新增分类成功')


@allure.feature('分类管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/flgl.yaml'))
@allure.title('分类管理_新增子分类')
def test_flgl_add01(browser, data):
    page = FlglPage(browser)
    page.input_treesearch(data['flmc'])
    page.icon_add()
    page.input_flmc(data['flmc1'])
    page.button_flqr()
    page.input_treesearch(data['flmc'])
    page.icon_add()
    page.input_flmc(data['flmc2'])
    page.button_flqr()
    page.input_treesearch(data['flmc'])
    page.assert_att(data['flmc1'])
    page.assert_att(data['flmc2'])
    logger.info('03新增子分类成功')


@allure.feature('分类管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/flgl.yaml'))
@allure.title('分类管理_编辑子分类')
def test_flgl_edit(browser, data):
    page = FlglPage(browser)
    page.input_treesearch(data['flmc'])
    page.icon_edit()
    page.input_flmc('s')
    page.button_flqr()
    page.input_treesearch(data['flmc'])
    page.assert_att(data['flmc1']+'s')
    logger.info("04编辑子分类成功")


@allure.feature('分类管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/flgl.yaml'))
@allure.title('分类管理_删除子分类')
def test_flgl_remove(browser, data):
    page = FlglPage(browser)
    page.input_treesearch(data['flmc'])
    page.icon_remove()
    page.assert_att("操作成功")
    logger.info("05子分类删除成功")


@allure.feature('分类管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/flgl1.yaml'))
@allure.title('分类管理_新增数据')
def test_flgl_sjadd(browser, data):
    page = FlglPage(browser)
    page.input_treesearch(data['flmc1'])
    page.icon_flmc()
    page.button_sjadd()
    page.input_sjflmc(data['sjflmc'])
    page.input_sjyjfl(data['flmc1'])
    page.input_sjejfl(data['flmc2'])
    page.input_sjsjsyz()
    page.input_sjtext(data['sjtext'])
    page.button_sjqr()
    page.assert_att('操作成功')
    logger.info('06新增数据成功')


@allure.feature('分类管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/flgl1.yaml'))
@allure.title('分类管理_查询数据')
def test_flgl_sjsearch(browser, data):
    page = FlglPage(browser)
    page.button_sjreset()
    page.input_sjsearch(data['sjflmc'])
    page.button_sjsearch()
    page.assert_att(data['sjtext'])
    logger.info("07查询数据成功")


@allure.feature('分类管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/flgl.yaml'))
@allure.title('分类管理_删除数据')
def test_flgl_sjremove(browser, data):
    page = FlglPage(browser)
    page.input_treesearch(data['flmc'])
    page.icon_flmc()
    page.icon_sjremove()
    page.assert_att("删除成功")
    page.icon_boxcheck()
    page.button_sjremove()
    page.input_treesearch(data['flmc1'])
    page.assert_att("暂无数据")
    logger.info("08删除数据成功")


@allure.feature('分类管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/flgl.yaml'))
@allure.title('分类管理_编辑数据')
def test_flgl_sjedit(browser, data):
    page = FlglPage(browser)
    page.input_treesearch(data['flmc'])
    page.icon_flmc()
    page.icon_sjedit()
    page.input_sjtext('aaa')
    page.button_sjqr()
    page.input_sjsearch('error')
    page.button_sjsearch()
    page.assert_att("暂无数据")
    page.button_sjreset()
    page.input_sjsearch("aaa")
    page.button_sjsearch()
    page.assert_att("aaa")
    logger.info("09编辑数据成功")


@allure.feature('分类管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/flgl.yaml'))
@allure.title('分类管理_删除总分类')
def test_flgl_sremove(browser, data):
    page = FlglPage(browser)
    page.input_treesearch(data['flmc'])
    page.icon_sremove()
    page.input_treesearch(data['flmc'])
    page.assert_att("暂无数据")
    logger.info("10子分类删除成功")


@allure.feature('分类管理')
@allure.title('退出登录')
def test_flgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')












import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjfw_page.jksxgl_page import JksxglPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('接口上线管理')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_jksxgl(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.wait(3)
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
    page.wait(2)
# 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info("接口上线管理_登录成功")


@allure.feature('接口上线管理')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_接口上线管理')
def test_menu_jksxgl(browser, data):
    page = MenuPage(browser)
    page.table_manage()
    page.menu_icon()
    page.menu_sjfw()
    page.sjfw_sjfw_jksxgl()
    logger.info('打开菜单_接口上线管理')
    # 切换iframe
    page.sjfw_jksxgl_iframe()
    logger.info('进入接口上线管理模块')
    page.assert_att("状态")


@allure.feature('接口上线管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/cjjk.yaml'))
@allure.title('查询接口')
def test_jksxgl_search(browser, data):
    page = JksxglPage(browser)
    page.input_search('error')
    page.button_search()
    page.assert_att('暂无数据')
    page.button_reset()
    page.input_search(data['jkmc2'])
    page.button_search()
    page.assert_att(data['jkmc2'])
    logger.info("接口上线管理_查询接口正常")


@allure.feature('接口上线管理')
@allure.title('测试接口')
def test_jksxgl_select(browser):
    page = JksxglPage(browser)
    page.button_select()
    page.assert_att("API测试")
    page.button_apitest()
    page.assert_att('200')
    page.button_back()
    logger.info('接口上线管理_测试接口')


@allure.feature('接口上线管理')
@allure.title('接口上下线')
def test_jksxgl_line(browser):
    page = JksxglPage(browser)
    page.button_line()
    page.wait(3)
    page.enter_keys()
    page.assert_att("离线")
    page.button_line()
    page.wait(3)
    page.enter_keys()
    page.assert_att('上线')
    logger.info('接口上线管理_接口上下线')


@allure.feature('接口上线管理')
@allure.title('退出登录')
def test_jksxgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')









# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class SjzlgzglPage(WebKeys):
    def button_add(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div[1]/div[1]/button[1]").click()
        self.wait(2)

    def input_rwmc(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div[4]/div/div/div[2]/form/div[1]/div/div/input").send_keys(word_keys)
        self.wait(2)

    def input_rulecode(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div[4]/div/div/div[2]/form/div[2]/div/div/div/input").send_keys(word_keys)
        self.wait(2)
        self.down_keys()
        self.wait(2)
        self.enter_keys()
        self.wait(2)

    def button_qr(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div[4]/div/div/div[3]/span/button[2]").click()
        self.wait(1)

    def input_search(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div[1]/div[3]/input").send_keys(word_keys)
        self.wait(2)
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div[1]/button[1]").click()
        self.wait(2)

    def button_reset(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div[1]/button[2]").click()
        self.wait(2)

    def button_action(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr/td[9]/div/button[1]").click()
        self.wait(2)
        self.enter_keys()
        self.wait(1)

    def button_edit(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr/td[9]/div/button[2]").click()
        self.wait(2)

    def button_remove(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr/td[9]/div/button[3]").click()
        self.wait(2)
        self.enter_keys()
        self.wait(2)



import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjgk_page.fjgl_page import FjglPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('分级管理')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_fjgl(browser, data):
    page = LoginPage(browser)
    browser.maximize_window()
    page.open(data["url"])
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
# 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info('------------进入分级管理模块-------------')


@allure.feature('分级管理')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_分类管理')
def test_menu_fjgl(browser, data):
    page = MenuPage(browser)
    page.table_manage()
    page.menu_icon()
    page.menu_sjgk()
    page.sjgk_sjflfj_sjfj()
    # 切换iframe
    page.sjgk_sjfj_iframe()
    page.assert_att("分级管理")
    logger.info('01进入菜单成功')


@allure.feature('分级管理')
@allure.title('版本管理_分级管理')
def test_local_verfjgl(browser):
    page = FjglPage(browser)
    page.button_vermg()
    page.assert_att("版本名称")
    logger.info("02切换tab版本管理成功")


@allure.feature('分级管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/fjgl.yaml'))
@allure.title('版本新增_分级管理')
def test_add_verfjgl(browser, data):
    page = FjglPage(browser)
    page.button_veradd()
    page.wait(2)
    page.input_verid(data['verid'])
    page.input_vername(data['vername'])
    page.input_vertext(data['vertext'])
    page.button_addline()
    page.input_mglevelid(data['mglevelid'])
    page.input_mglevelname(data['mglevelname'])
    page.input_mgleveldetail(data['mgleveldetail'])
    page.box_checkture()
    page.button_addline()
    page.input_mglevelid1(data['mglevelid1'])
    page.input_mglevelname1(data['mglevelname1'])
    page.input_mgleveldetail1(data['mgleveldetail1'])
    page.box_checkture1()
    page.button_levelqr()
    page.assert_att("操作成功")
    logger.info("03版本新增成功")


@allure.feature('分级管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/fjgl.yaml'))
@allure.title('版本查询_分级管理')
def test_search_verfjgl(browser, data):
    page = FjglPage(browser)
    page.input_mgsearch('error')
    page.assert_att('暂无数据')
    page.button_mgreset()
    page.input_mgsearch(data["verid"])
    page.assert_att(data["verid"])
    logger.info('04版本查询成功')


@allure.feature('分级管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/fjgl.yaml'))
@allure.title('版本启用_分级管理')
def test_switch_verfjgl(browser, data):
    page = FjglPage(browser)
    page.button_switch()
    page.assert_att("禁用")
    page.button_fjgl()
    page.button_reset()
    page.assert_att(data['mglevelname'])
    page.assert_att(data['mglevelname1'])
    logger.info('05版本启用并切换tab分级管理成功')


@allure.feature('分级管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/fjgl.yaml'))
@allure.title('新增分级_分级管理')
def test_add_fjgl(browser, data):
    page = FjglPage(browser)
    page.button_sjadd()
    page.input_sjlevel(data['level'])
    page.input_sjlevelname(data['levelname'])
    page.input_sjleveldetail(data['leveldetail'])
    page.input_sjremark(data['remark'])
    page.button_sjqr()
    page.assert_att("操作成功")
    logger.info('06新增分级成功')


@allure.feature('分级管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/fjgl.yaml'))
@allure.title('查询分级_分级管理')
def test_search_fjgl(browser, data):
    page = FjglPage(browser)
    page.input_search('error')
    page.assert_att("暂无数据")
    page.button_reset()
    page.input_search(data["levelname"])
    page.assert_att(data['levelname'])
    logger.info('07分级查询成功')


@allure.feature('分级管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/fjgl.yaml'))
@allure.title('编辑分级_分级管理')
def test_edit_fjgl(browser, data):
    page = FjglPage(browser)
    page.button_sjedit()
    page.input_sjremark('aaa')
    page.button_sjqr()
    page.button_reset()
    page.input_search('aaa')
    page.assert_att('aaa')
    logger.info('08分级编辑成功')


@allure.feature('分级管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/fjgl.yaml'))
@allure.title('删除分级_分级管理')
def test_remove_fjgl(browser, data):
    page = FjglPage(browser)
    page.button_remove()
    page.assert_att('暂无数据')
    logger.info('09分级删除成功')


@allure.feature('分级管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/fjgl.yaml'))
@allure.title('版本编辑_分级管理')
def test_edit_verfjgl(browser, data):
    page = FjglPage(browser)
    page.button_vermg()
    page.button_veredit()
    page.input_vertext("sss")
    page.button_levelqr()
    page.button_mgreset()
    page.input_mgsearch(data['vertext']+'sss')
    page.assert_att(data['vertext']+'sss')
    logger.info('10版本编辑成功')


@allure.feature('分级管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/fjgl.yaml'))
@allure.title('版本删除_分级管理')
def test_remove_verfjgl(browser, data):
    page = FjglPage(browser)
    page.button_verremove()
    page.assert_att("请先禁用该版本")
    page.button_switch()
    page.button_verremove()
    page.enter_keys()
    page.assert_att("操作成功")
    page.button_mgreset()
    page.input_mgsearch(data["verid"])
    page.assert_att("暂无数据")
    logger.info('11版本删除成功')


@allure.feature('分级管理')
@allure.title('退出登录')
def test_fjgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')



# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class QxglPage(WebKeys):
    def input_user(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/div/div/div/input").send_keys(search_key)
        self.wait(2)
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[1]/span").click()
        self.wait(2)

    def button_refresh(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/button[2]/span").click()

    def button_jksq(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/div[4]/div[2]/table/tbody/tr/td[7]/div/button").click()
        self.wait(2)

    def input_jkls(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div[2]/div[1]/div/div[1]/input").send_keys(search_key)
        self.wait(2)

    def box_alljk(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div[2]/div[1]/p/label/span[1]").click()

    def box_allsq(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div[2]/div[3]/p/label/span[1]").click()

    def box_jkls(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div[2]/div[1]/div/div[2]/label/span[1]").click()

    def box_sqls(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div[2]/div[3]/div/div[2]/label/span[1]").click()

    def button_sq(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div[2]/div[2]/button[2]").click()

    def button_qxsq(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div[2]/div[2]/button[1]").click()

    def button_qr(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[3]/span/button[2]").click()



# import os
# from time import sleep
# from selenium import webdriver
# from framework.key_word.keyword_web import WebKeys
# import pytest
#
#
# @pytest.fixture(scope="function")
# def t():
#     t = webdriver.Chrome()
#     t.get("http://eid.csrc.gov.cn/")
#     sleep(3)
#     print("打开浏览器")
#
#     yield t
#     t.quit()
#
#
#
#
#
#
#
#



# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class TmgzPage(WebKeys):
    def input_search(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[1]/div[1]/div/input").send_keys(word_keys)
        self.wait(2)
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[1]/div[1]/button[1]").click()
        self.wait(5)

    def button_reset(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[1]/div[1]/button[2]").click()
        self.wait(2)

    def button_remove(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[1]/div[2]/button[2]").click()
        self.wait(2)
        self.enter_keys()
        self.wait(2)

    # 新增
    def button_add(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[1]/div[2]/button[1]").click()
        self.wait(2)

    def input_gzmc(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[4]/div/div[2]/div/form/div[1]/div/div[1]/input").send_keys(word_keys)
        self.wait(2)

    def input_egzmc(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[5]/div/div[2]/div/form/div[1]/div/div/input").send_keys(word_keys)
        self.wait(2)

    def input_gzbm(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[4]/div/div[2]/div/form/div[2]/div/div[1]/input").send_keys(word_keys)
        self.wait(2)

    def input_gzdj(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[4]/div/div[2]/div/form/div[3]/div/div/div/input").clear()
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[4]/div/div[2]/div/form/div[3]/div/div/div/input").send_keys(word_keys)
        self.wait(2)

    def input_bds(self, word_keys, word_keys1):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[4]/div/div[2]/div/form/div[5]/div/div[1]/input").send_keys(word_keys)
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[4]/div/div[2]/div/form/div[5]/div/div[2]/input").send_keys(word_keys1)
        self.wait(2)

    def input_thfh(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[4]/div/div[2]/div/form/div[6]/div/div[1]/input").send_keys(word_keys)
        self.wait(2)

    def input_gzlx(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[4]/div/div[2]/div/form/div[4]/div/div/div/input").click()
        self.wait(1)
        self.up_keys()
        self.wait(1)
        self.enter_keys()
        self.wait(2)

    def input_gzmy(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[4]/div/div[2]/div/form/div[6]/div/div[1]/input").send_keys(word_keys)

    def input_gzms(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[4]/div/div[2]/div/form/div[7]/div/div/textarea").send_keys(word_keys)

    def button_save(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[4]/div/div[3]/div/button[2]").click()

    def button_esave(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[5]/div/div[3]/div/button[2]").click()
        self.wait(5)

    def button_setting(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[1]/div[2]/button[2]").click()
        self.wait(2)

    def button_edit(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr[1]/td[13]/div/div/button[1]").click()
        self.wait(2)

    def button_eremove(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[2]/div[5]/div[2]/table/tbody/tr[1]/td[13]/div/div/button[2]").click()
        self.wait(2)
        self.enter_keys()
        self.wait(5)

    def box_check(self):
        self.locator("xpath", "//*[@id='app']/section/div/div/div/div/div/div[2]/div[4]/div[2]/table/tbody/tr/td[1]/div/label/span/span").click()
        self.wait(2)







# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys
import time


class BaiduPage(WebKeys):
    url = "http://www.baidu.com"

    def search_input(self, search_key):
        self.locator("id", "kw").send_keys(search_key)

    def search_button(self):
        self.locator("id", "su").click()

    def button_ssgs(self):
        self.locator("xpath", "/html/body/div[2]/ul/li[3]/a").click()

    def get_screen(self):
        now_time = time.strftime('%Y_%m_%d_%H_%M_%S')
        self.driver.get_screenshot_as_file(f'{now_time}.jpg')




import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjgk_page.tmgl_page import TmglPage
from yhproject_pkg.framework.page.sjgk_page.tmgz_page import TmgzPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('脱敏管理')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_tmgl(browser, data):
    page = LoginPage(browser)
    browser.get(data['url'])
    page.driver.maximize_window()
    page.wait(3)
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
    # 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info('------------进入脱敏管理模块-------------')


@allure.feature('脱敏管理')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_脱敏管理')
def test_menu_tmgl(browser, data):
    page = MenuPage(browser)
    page.driver.maximize_window()
    page.table_manage()
    page.menu_icon()
    page.menu_sjgk()
    page.sjgk_sjaq_tmgl()
    # 切换iframe
    page.sjgk_tmgl_iframe()
    page.assert_att("脱敏规则")
    logger.info('01进入菜单')


@allure.feature('脱敏管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/tmgz.yaml'))
@allure.title('查询_脱敏管理')
def test_search_tmgl(browser, data):
    page = TmglPage(browser)
    page.input_search('error')
    page.assert_att('暂无数据')
    page.button_reset()
    page.input_search(data['table'])
    page.assert_att(data['table'])
    logger.info('02查询成功')


@allure.feature('脱敏管理')
@allure.title('管理_脱敏管理')
def test_mgtmgl(browser):
    page = TmglPage(browser)
    page.button_manage()
    page.core_switch()
    page.core_switch()
    logger.info('03启停成功')


@allure.feature('脱敏管理')
@allure.title('删除_脱敏管理')
def test_rmtmgl(browser):
    page = TmglPage(browser)
    page.button_remove()
    page.assert_att("暂无数据")
    logger.info('04删除成功')


@allure.feature('脱敏管理')
@allure.title('返回_脱敏规则')
def test_rebacktmgz(browser):
    page = MenuPage(browser)
    page.reback_iframe()
    page.menu_sjgk()
    page.sjgk_sjaq_tmgz()
    page.sjgk_tmgz_iframe()
    page.assert_att("规则名称")
    logger.info('05重返脱敏规则菜单')


@allure.feature('脱敏管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/tmgz.yaml'))
@allure.title('删除_脱敏规则')
def test_rmtmgz(browser, data):
    page = TmgzPage(browser)
    page.input_search(data['gzmc2'])
    page.button_setting()
    page.button_eremove()
    page.assert_att("暂无数据")
    logger.info('06删除脱敏规则数据')


@allure.feature('脱敏管理')
@allure.title('退出登录')
def test_tmgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')



import pytest
import pyautogui
import random
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjfw_page.jkcj_page import JkcjPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('接口创建')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_jkcj(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
# 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info("创建接口_登录成功")


@allure.feature('接口创建')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_接口创建')
def test_menu_jkcj(browser, data):
    page = MenuPage(browser)
    page.table_manage()
    page.menu_icon()
    page.menu_sjfw()
    page.sjfw_sjfw_jkcj()
    # 切换iframe
    page.sjfw_jkcj_iframe()
    page.assert_att("接口名称")
    logger.info('打开菜单_接口创建')


@allure.feature('接口创建')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/cjjk.yaml'))
@allure.title('新增接口1')
def test_jkcj_add1(browser, data):
    page = JkcjPage(browser)
    page.button_add()
    rand = random.randint(0, 100000)
    page.input_sjymc(data["sjymc"])
    page.input_sjbmc(data["sjbmc"])
    page.drog_aa()
    page.wait(3)
    page.button_jkcs1()
    page.button_jkcs2()
    page.input_jkbm(data['jkbm1'])
    page.input_jkbm(rand)
    page.input_jkmc(data['jkmc1'])
    page.input_ywzt()
    page.input_jkms(data['jkms1'])
    page.button_save()
    page.wait(1)
    page.assert_att("操作成功")
    logger.info("新增接口_新增接口成功")


@allure.feature('接口创建')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/cjjk.yaml'))
@allure.title('新增接口2')
def test_jkcj_add2(browser, data):
    page = JkcjPage(browser)
    page.button_add()
    rand = random.randint(0, 100000)
    page.input_sjymc(data["sjymc"])
    page.input_sjbmc(data["sjbmc"])
    page.drog_aa()
    page.wait(3)
    page.button_jkcs1()
    page.button_jkcs2()
    page.input_jkbm(data['jkbm2'])
    page.input_jkbm(rand)
    page.input_jkmc(data['jkmc2'])
    page.input_ywzt()
    page.input_jkms(data['jkms2'])
    page.button_save()
    page.wait(1)
    page.assert_att("操作成功")
    logger.info("新增接口_新增接口成功")


@allure.feature('接口创建')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/cjjk.yaml'))
@allure.title('查询接口')
def test_jkcj_search(browser, data):
    page = JkcjPage(browser)
    page.input_seach_jkmc('error')
    page.button_search()
    page.assert_att('暂无数据')
    page.button_reset()
    page.input_seach_jkmc(data['jkmc1'])
    page.button_search()
    page.assert_att(data['jkmc1'])
    logger.info("查询接口正常")


@allure.feature('接口创建')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/cjjk.yaml'))
@allure.title('接口测试')
def test_jkcj_apitest(browser, data):
    page = JkcjPage(browser)
    page.button_reset()
    page.input_seach_jkmc(data['jkmc1'])
    page.button_search()
    page.button_test()
    page.assert_att("接口信息")
    page.button_apitest()
    page.assert_att("200")
    page.input_edit_jkms("已经测试")
    page.button_edit_save()
    page.button_edit_back()
    page.button_search()
    page.assert_att("已经测试")
    logger.info("编辑测试成功")


@allure.feature('接口创建')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/cjjk.yaml'))
@allure.title('提交接口')
def test_jkcj_sumbit(browser, data):
    page = JkcjPage(browser)
    page.button_reset()
    page.input_seach_jkmc(data['jkmc1'])
    page.button_search()
    page.button_submit()
    page.enter_keys()
    page.assert_att('审核中')
    page.button_reset()
    page.input_seach_jkmc(data['jkmc2'])
    page.button_search()
    page.button_submit()
    page.enter_keys()
    page.assert_att('审核中')
    logger.info('新增接口_提交接口审核')


@allure.feature('接口创建')
@allure.title('退出登录')
def test_jkcj_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')





# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class YwztglPage(WebKeys):
    # 新增
    def button_add(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/button[1]").click()

    def input_ztmc(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[3]/div/div/div[2]/form/div[1]/div[1]/div/div/div[1]/div/input").send_keys(words_key)
        self.wait(3)

    def input_sjzt(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[3]/div/div/div[2]/form/div[1]/div[2]/div/div/div/div[1]/div[1]/div[2]/input").send_keys(words_key)
        self.down_keys()
        self.enter_keys()

    def input_order(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[3]/div/div/div[2]/form/div[2]/div[2]/div/div/div/div/input").send_keys(words_key)

    def input_ztms(self, words_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[3]/div/div/div[2]/form/div[3]/div/div/div/textarea").send_keys(words_key)

    def button_qr(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[3]/div/div/div[3]/span/button[2]").click()
        self.wait(3)

    # 查询
    def input_search(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/form/div/div[1]/div/div/div/input").send_keys(search_key)
        self.wait(1)
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/form/div/div[2]/div/div/button[1]").click()
        self.wait(2)

    def button_reset(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/form/div/div[2]/div/div/button[2]").click()
        self.wait(2)

    # 编辑
    def button_edit(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div/div/div[2]/div[2]/table/tbody/tr[1]/td[6]/div/button[1]").click()
        self.wait(2)

    # 删除
    def button_remove(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div/div/div[2]/div[2]/table/tbody/tr[1]/td[6]/div/button[2]").click()
        self.wait(2)



# 从关键字文件导入基类
from yhproject_pkg.framework.key_word.keyword_web import WebKeys


class MenuPage(WebKeys):
    def table_manage(self):
        self.locator("xpath", "/html/body/section/div/span/ul/li[2]/span").click()
        self.wait(3)

    def menu_icon(self):
        self.locator("xpath", "/html/body/section/div/div[1]/div/i").click()
        self.wait(3)

    # 数据开发
    def menu_sjkf(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/section/ul/li[1]/div/span").click()
        self.wait(3)

    # 数据管控
    def menu_sjgk(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/section/ul/li[2]/div/span").click()
        self.wait(3)

    # 数据分类分级
    def sjgk_sjflfj_sjfl(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[4]/dd[1]").click()
        self.wait(3)

    def sjgk_sjflfj_sjfj(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[4]/dd[2]").click()
        self.wait(3)

    def sjgk_sjfl_iframe(self):
        self.switch_iframe("id", "yhdgp:controll:classification:sensitivityLevel")
        self.wait(3)

    def sjgk_sjfj_iframe(self):
        self.switch_iframe("id", "yhdgp:controll:classification:dataClassification")
        self.wait(3)

    # 脱敏规则
    def sjgk_sjaq_tmgz(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[5]/dd[1]").click()
        self.wait(3)

    def sjgk_tmgz_iframe(self):
        self.switch_iframe("id", "yhdgp:controll:dataSafe:antianaphylaxisRule")
        self.wait(3)

    # 数据脱敏
    def sjgk_sjaq_sjtm(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[5]/dd[2]").click()
        self.wait(3)

    def sjgk_sjtm_iframe(self):
        self.switch_iframe("id", "yhdgp:controll:dataSafe:dataAntianaphylaxis")
        self.wait(3)

    # 脱敏管理
    def sjgk_sjaq_tmgl(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[5]/dd[3]").click()
        self.wait(3)

    def sjgk_tmgl_iframe(self):
        self.switch_iframe("id", "yhdgp:controll:dataSafe:antianaphylaxisManage")
        self.wait(3)

    # 规则库管理
    def sjgk_sjzl_gzkgl(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[3]/dd[1]").click()
        self.wait(3)

    def sjgk_gzkgl_iframe(self):
        self.switch_iframe("id", "yhdgp:controll:dataQuality:ruleBase")
        self.wait(3)

    # 数据质量规则管理
    def sjgk_sjzl_sjzlgzgl(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[3]/dd[2]").click()
        self.wait(3)

    def sjgk_sjzlgzgl_iframe(self):
        self.switch_iframe("id", "yhdgp:controll:dataQuality:dataRuleManage")
        self.wait(3)

    # 数据服务
    def menu_sjfw(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/section/ul/li[6]/div/span").click()
        self.wait(3)

    # 数据开发-采集中心-调度管理
    def sjkf_cjzx_ddgl(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[1]/dd[4]").click()
        self.wait(3)

    def sjkf_ddgl_iframe(self):
        self.switch_iframe("id", "yhdgp:dev:collection:diaodu")
        self.wait(3)

    # 数据开发-元数据-元数据管理
    def sjgk_ysj_ysjgl(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[1]/dd[2]").click()
        self.wait(5)

    def sjgk_ysjgl_iframe(self):
        self.switch_iframe("id", "yhdgp:controll:metaData:metaDataManage")
        self.wait(3)

    # 数据服务-数据服务-权限管理
    def sjfw_sjfw_qxgl(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[2]/dd[1]").click()
        self.wait(3)

    def sjfw_qxgl_iframe(self):
        self.switch_iframe("id", "yhdgp:dataApplication:dataServer:sourceAuthorize")
        self.wait(3)

    # 数据服务-数据服务-业务主题管理
    def sjfw_sjfw_ywztgl(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[2]/dd[2]").click()
        self.wait(3)

    def sjfw_yeztgl_iframe(self):
        self.switch_iframe("id", "yhdgp:dataApplication:dataServer:apiTheme")
        self.wait(3)

    # 数据服务-数据服务-接口创建
    def sjfw_sjfw_jkcj(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[2]/dd[3]").click()
        self.wait(3)

    def sjfw_jkcj_iframe(self):
        self.switch_iframe("id", "yhdgp:dataApplication:dataServer:apiAdd")
        self.wait(3)

    # 数据服务-数据服务-接口审批
    def sjfw_sjfw_jksp(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[2]/dd[4]").click()
        self.wait(3)

    def sjfw_jksp_iframe(self):
        self.switch_iframe("id", "yhdgp:dataApplication:dataServer:apiReview")
        self.wait(3)

    # 数据服务-数据服务-接口上线管理
    def sjfw_sjfw_jksxgl(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[2]/dd[5]").click()
        self.wait(3)

    def sjfw_jksxgl_iframe(self):
        self.switch_iframe("id", "yhdgp:dataApplication:dataServer:apiOnline")
        self.wait(3)

    # 数据服务-数据服务-接口查询
    def sjfw_sjfw_jkcx(self):
        self.locator("xpath", "/html/body/section/div/section[2]/section/div[1]/section/div/div/div[2]/div/dl[2]/dd[6]").click()
        self.wait(3)

    def sjfw_jkcx_iframe(self):
        self.switch_iframe("id", "yhdgp:dataApplication:dataServer:apiList")
        self.wait(3)




import setuptools
with open("README.md", "r") as fh:
    long_description = fh.read()
    setuptools.setup(
        name="yhproject_pkg_0.02",
        version="0.0.2",
        author="HUXIAOFENG",
        author_email="474025548@qq.com",
        description="A small example package",
        long_description=long_description,
        long_description_content_type="text/markdown",
        url="https://github.com/pypa/sampleproject",
        packages=setuptools.find_packages(),
        classifiers=[
              "Programming Language :: Python :: 3",
              "License :: OSI Approved :: MIT License",
              "Operating System :: OS Independent",
        ],
    )



import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('测试登录')
@allure.title('打开登录页面')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.assert_att("赢和数据")
    logger.info('打开登录页面')


@allure.feature('测试登录')
@allure.title('账号密码均为空')
def test_login1(browser):
    page = LoginPage(browser)
    page.button_login()
    page.assert_att("用户名为空")
    logger.info("账号密码均为空")


@allure.feature('测试登录')
@allure.title('密码为空')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login2(browser, data):
    page = LoginPage(browser)
    page.input_user(data["user"])
    page.button_login()
    page.assert_att("密码为空")
    page.clear_user()
    logger.info("密码为空")


@allure.feature('测试登录')
@allure.title('密码不正确')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login3(browser, data):
    page = LoginPage(browser)
    page.input_user(data["user"])
    page.input_password("123456")
    page.button_login()
    page.assert_att("密码不正确")
    page.clear_user()
    page.clear_password()
    logger.info("密码不正确")


@allure.feature('测试登录')
@allure.title('密码账号正确登录成功')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login4(browser, data):
    page = LoginPage(browser)
    page.clear_user()
    page.input_user(data["user"])
    page.clear_password()
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
# 登录跳转
    page.switch_window(-1)
    page.assert_att("数据管控")
    logger.info("登录成功")


@allure.feature('测试登录')
@allure.title('退出登录')
def test_login_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')




import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjfw_page.qxgl_page import QxglPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('权限管理')
@allure.title('登录')
@pytest.mark.run(order=15)
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_gxgl(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
# 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info('------------进入权限管理管理模块-------------')


@allure.feature('权限管理')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@pytest.mark.run(order=16)
@allure.title('打开菜单_权限管理')
def test_menu_qxgl(browser, data):
    page = MenuPage(browser)
    page.table_manage()
    page.menu_icon()
    page.menu_sjfw()
    page.sjfw_sjfw_qxgl()
# 切换iframe
    page.sjfw_qxgl_iframe()
    page.assert_att("用户名")
    logger.info('01打开菜单')


@allure.feature('权限管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/qxgl.yaml'))
@pytest.mark.run(order=17)
@allure.title('查询用户')
def test_qxgl_search(browser, data):
    page = QxglPage(browser)
    page.input_user(data["user"])
    page.wait(2)
    page.assert_att("huxiaofeng")
    page.button_refresh()
    page.input_user("error")
    page.assert_att("暂无数据")
    page.button_refresh()
    logger.info("02授权用户查询成功")


@allure.feature('权限管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjfw/qxgl.yaml'))
@pytest.mark.run(order=18)
@allure.title('授权用户')
def test_qxgl_jksq(browser, data):
    page = QxglPage(browser)
    page.input_user(data["user"])
    page.button_jksq()
    page.assert_att("接口列表")
    page.box_alljk()
    page.button_sq()
    page.box_allsq()
    page.button_qxsq()
    page.input_jkls(data["jkls"])
    page.box_jkls()
    page.button_sq()
    page.box_sqls()
    page.button_qxsq()
    page.button_qr()
    logger.info("03授权/取消授权成功")


@allure.feature('权限管理')
@allure.title('退出登录')
def test_qxgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')




from yhproject_pkg.framework.key_word.keyword_web import WebKeys
from selenium.webdriver.common.keys import Keys


class DdglPage(WebKeys):

    # 新增任务
    def button_add(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[1]/div[1]/button[1]").click()
        self.wait(3)

    def input_rwlx(self, word_keys):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div/form/div[1]/div/div/div/input").send_keys(word_keys)
        self.wait(2)
        self.down_keys()
        self.enter_keys()

    def input_rwmc(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div/form/div[2]/div/div[1]/div/input").send_keys(search_key)

    def input_url(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div/form/div[3]/div/div[1]/div/input").send_keys(search_key)

    def input_qqlx(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div/form/div[4]/div/div/div/input").send_keys(search_key)
        self.wait(1)
        self.down_keys()
        self.down_keys()
        self.wait(1)
        self.enter_keys()

    def input_jjrzx(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div/form/div[5]/div/label[2]/span[1]/span").click()

    def input_rwms(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div/form/div[6]/div/div/div/textarea").send_keys(search_key)

    def button_add_qr(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[3]/span/button[2]").click()
        self.wait(3)

    # 查询任务
    def search_rwmc(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/div[1]/div/div/div/input").clear()
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/div[1]/div/div/div/input").send_keys(search_key)

    def search_rwlx(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/div[2]/div/div/div/input").send_keys(search_key)
        self.wait(2)
        self.down_keys()
        self.enter_keys()

    def button_search(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/div[3]/div/button[1]").click()
        self.wait(3)

    def button_refresh(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[1]/div/form/div[3]/div/button[2]").click()

    # 停用/启用/编辑/删除
    def button_switch(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div/div/div[2]/div[2]/table/tbody/tr/td[10]/div/button[3]/i").click()
        self.wait(3)
        self.enter_keys()
        self.wait(2)

    def button_edit(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div/div/div[2]/div[2]/table/tbody/tr/td[10]/div/button[1]").click()

    def edit_rwmc(self, search_key):
        self.locator("xpath", "//*[@id='app']/section/div/div[3]/div/div/div[2]/div/form/div[2]/div/div/div/input").send_keys(search_key)

    def button_delete(self):
        self.locator("xpath", "//*[@id='app']/section/div/div[2]/div/div[2]/div/div/div[2]/div[2]/table/tbody/tr/td[10]/div/button[2]").click()

    def windows_enter(self):
        self.locator("xpath", "/html/body/div[6]/div").send_keys(Keys.ENTER)









import pytest
from selenium import webdriver
import allure
# 作者-上海悠悠 QQ交流群:717225969
# blog地址 https://www.cnblogs.com/yoyoketang/

def test_login(browser):
    with allure.step("step1：打开登录首页"):
        browser.get("http://www.manongjc.com/detail/14-pcbktsxmwrmyvrx.html")
    # 故意断言失败，看是否会截图
    assert browser.title == "悠悠"



from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.demo_page0 import BaiduPage
import pytest
import allure

@allure.feature('百度搜索')
# class TestBaidu():
#     @classmethod
#     def setup_class(cls):
#         cls.driver = webdriver.Chrome()

@allure.title('测试用例1')
@pytest.mark.parametrize('data', load_yaml('../../data/demo/login_demo1.yaml'))
@pytest.mark.run(order=1)
def test_login00(data, browser):
    browser.get(data['url'])
    page = BaiduPage(browser)
    page.driver.maximize_window()
    page.wait(5)
    print('打开浏览器成功')
    page.locator(data["name1"], data["value1"]).click()
    print('测试1')
    page.assert_att("huxiaofeng")

@allure.title('测试用例2')
@pytest.mark.parametrize('data', load_yaml('../../data/demo/login_demo1.yaml'))
@pytest.mark.run(order=2.1)
def test_login01(data, browser):
    page = BaiduPage(browser)
    page.locator(data["name1"], data["value4"]).click()
    page.wait(5)

@allure.title('测试用例3')
@pytest.mark.parametrize('data', load_yaml('../../data/demo/login_demo1.yaml'))
@pytest.mark.run(order=2.2)
def test_login02(data, browser):
    page = BaiduPage(browser)
    page.locator(data["name1"], data["value5"]).click()
    page.wait(5)

@allure.title('测试用例4')
@pytest.mark.parametrize('data', load_yaml('../../data/demo/login_demo1.yaml'))
@pytest.mark.run(order=3)
def test_loginxp(data, browser):
    page = BaiduPage(browser)
    page.locator(data["name1"], data["value6"]).click()
    page.wait(5)







import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjgk_page.sjzlgzgl_page import SjzlgzglPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('数据质量规则管理')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_zlgzgl(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
    # 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info('------------进入数据管控质量规则管理模块-------------')


@allure.feature('数据质量规则管理')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_质量规则管理')
def test_menu_zlgzgl(browser, data):
    page = MenuPage(browser)
    page.table_manage()
    page.menu_icon()
    page.menu_sjgk()
    page.sjgk_sjzl_sjzlgzgl()
    # 切换iframe
    page.sjgk_sjzlgzgl_iframe()
    page.assert_att("任务名称")
    logger.info('01进入菜单成功')


@allure.feature('数据质量规则管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/sjzlgzgl.yaml'))
@allure.title('新增_质量规则管理')
def test_add_zlgzgl(browser, data):
    page = SjzlgzglPage(browser)
    page.button_add()
    page.input_rwmc(data['rwmc'])
    page.input_rulecode(data['rulecode'])
    page.button_qr()
    page.assert_att('操作成功')
    logger.info('02新增成功')


@allure.feature('数据质量规则管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/sjzlgzgl.yaml'))
@allure.title('查询_质量规则管理')
def test_search_zlgzgl(browser, data):
    page = SjzlgzglPage(browser)
    page.input_search('error')
    page.assert_att('暂无数据')
    page.button_reset()
    page.input_search(data['rwmc'])
    page.assert_att(data['rwmc'])
    logger.info('03查询成功')


@allure.feature('数据质量规则管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/sjzlgzgl.yaml'))
@allure.title('执行_质量规则管理')
def test_aciton_zlgzgl(browser, data):
    page = SjzlgzglPage(browser)
    page.button_action()
    page.assert_att('操作成功')
    logger.info('04执行规则成功')


@allure.feature('数据质量规则管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/sjzlgzgl.yaml'))
@allure.title('编辑_质量规则管理')
def test_edit_zlgzgl(browser, data):
    page = SjzlgzglPage(browser)
    page.button_edit()
    page.input_rwmc('s')
    page.button_qr()
    page.button_reset()
    page.input_search(data['rwmc']+'s')
    page.assert_att(data['rwmc']+'s')
    logger.info('05编辑成功')


@allure.feature('数据质量规则管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjgk/sjzlgzgl.yaml'))
@allure.title('删除_质量规则管理')
def test_remove_zlgzgl(browser, data):
    page = SjzlgzglPage(browser)
    page.button_remove()
    page.assert_att('暂无数据')
    logger.info('06删除成功')


@allure.feature('数据质量规则管理')
@allure.title('退出登录')
def test_zlgzgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')







import pytest
import pyautogui
from yhproject_pkg.framework.data_driver.yaml_driver import load_yaml
from yhproject_pkg.framework.page.login_page.login_page import LoginPage
from yhproject_pkg.framework.page.login_page.menu_page import MenuPage
from yhproject_pkg.framework.page.sjkf_page.ddgl_page import DdglPage
import allure
import logging

logger = logging.getLogger(__name__)


@allure.feature('调度管理')
@allure.title('登录')
@pytest.mark.parametrize('data', load_yaml('../../data/login/login1.yaml'))
def test_login_ddgl(browser, data):
    page = LoginPage(browser)
    page.driver.maximize_window()
    page.open(data["url"])
    page.input_user(data["user"])
    page.input_password(data["password"])
    page.button_remember()
    page.button_login()
    page.wait(2)
# 登录跳转
    page.switch_window(-1)
    page.assert_att("赢和数据")
    logger.info('------------进入元调度管理模块-------------')


@allure.feature('调度管理')
@pytest.mark.parametrize('data', load_yaml('../../data/login/menu.yaml'))
@allure.title('打开菜单_调度管理')
def test_menu_ddgl(browser, data):
    page = MenuPage(browser)
    page.table_manage()
    page.menu_icon()
    page.menu_sjkf()
    page.sjkf_cjzx_ddgl()
    logger.info('打开菜单_调度管理')
# 切换iframe
    page.sjkf_ddgl_iframe()
    page.assert_att("任务名称")
    logger.info('01打开菜单_调度管理')


@allure.feature('调度管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjkf/ddgl.yaml'))
@allure.title('新增调度任务')
def test_ddgl_add(browser, data):
    page = DdglPage(browser)
    page.button_add()
    page.input_rwlx(data["rwlx"])
    page.input_rwmc(data["rwmc"])
    page.input_url(data["url"])
    page.input_qqlx(data["qqlx"])
    page.input_jjrzx()
    page.input_rwms(data["rwms"])
    page.button_add_qr()
    page.assert_att(data["rwmc"])
    logger.info('02新增调度任务成功')


@allure.feature('调度管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjkf/ddgl.yaml'))
@allure.title('查询调度任务')
def test_ddgl_search(browser, data):
    page = DdglPage(browser)
    page.search_rwmc(data["rwmc"])
    page.search_rwlx(data['rwlx'])
    page.button_search()
    page.assert_att(data["rwmc"])
    page.button_refresh()
    page.search_rwmc("error")
    page.button_search()
    page.assert_att("暂无数据")
    page.button_refresh()
    page.button_search()
    page.assert_att(data["rwmc"])
    logger.info("03查询调度任务正常")


@allure.feature('调度管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjkf/ddgl.yaml'))
@allure.title('切换调度启停开关')
def test_ddgl_switch(browser, data):
    page = DdglPage(browser)
    page.search_rwmc(data["rwmc"])
    page.button_search()
    page.button_switch()
    page.assert_att("停用")
    page.button_switch()
    page.assert_att("启用")
    logger.info("04切换调度启停开关正常")


@allure.feature('调度管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjkf/ddgl.yaml'))
@allure.title('编辑调度任务')
def test_ddgl_edit(browser, data):
    page = DdglPage(browser)
    page.search_rwmc(data["rwmc"])
    page.button_search()
    page.button_switch()
    page.button_edit()
    page.edit_rwmc('s')
    page.button_add_qr()
    page.button_refresh()
    page.search_rwmc(data["rwmc"]+'s')
    page.button_search()
    page.assert_att(data["rwmc"]+'s')
    logger.info("05编辑调度任务正常")


@allure.feature('调度管理')
@pytest.mark.parametrize('data', load_yaml('../../data/sjkf/ddgl.yaml'))
@allure.title('删除调度任务')
def test_ddgl_remove(browser, data):
    page = DdglPage(browser)
    page.search_rwmc(data["rwmc"]+'s')
    page.button_delete()
    page.enter_keys()
    page.search_rwmc(data["rwmc"]+'s')
    page.assert_att("暂无数据")
    logger.info("06删除调度任务正常")


@allure.feature('调度管理')
@allure.title('退出登录')
def test_ddgl_logout(browser):
    page = LoginPage(browser)
    page.reback_iframe()
    page.button_user()
    pyautogui.click(2428, 391)
    page.wait(2)
    page.assert_att("赢和数据")
    logger.info('.....退出登录.....')





# import pytest
# from selenium import webdriver
# from framework.data_driver.yaml_driver import load_yaml
# from framework.page.demo_page0 import BaiduPage
#
#
#
#
# class TestLogin:
#     driver = webdriver.Chrome()
#
#     @pytest.mark.parametrize('data', load_yaml('../../data/demo/login_demo2.yaml'))
#     def test_login012(self,data,t):
#         page = BaiduPage(self.driver)
#         print("还在当前页面")
#         tpage.locator(data["name1"], data["value2"]).click()
#         page.wait(1)
#         print('测试3')
#
#
#
#
